@@ -109,7 +109,6 @@ def edit_clip(clip, start_on_timeline, end_on_timeline, in_point_on_clip, out_po
     :param end_on_timeline: (int) Frame at which the clip should end in the sequence timeline
     :param in_point_on_clip: (int) First frame we will see of the clip (in the clip own timeline)
     :param out_point_on_clip: (int) Last frame we will see of the clip (in the clip own timeline)
-    :param out_point_on_clip: (int) Last frame we will see of the clip (in the clip own timeline)
     """
     # get clip fps if no fps given
     if fps is None:
@@ -233,5 +232,29 @@ def has_media_encoder():
     return premiere_version in encoder_versions
 
 
+def clone_sequence(sequence, new_sequence_name=None):
+    """
+    Equivalent of Sequence.clone() with return value and optional rename
+    :param sequence: (Sequence) sequence object to duplicate
+    :param new_sequence_name: (str or None) optional new name for the duplicated sequence
+    :return: (Sequence) duplicated sequence object
+    """
+    project = pymiere.objects.app.project
+    # store sequences before clone
+    before_sequence_names = [s.sequenceID for s in project.sequences]
+    # actual clone
+    sequence.clone()
+    # search clone sequence
+    for new_seq in project.sequences:
+        if new_seq.sequenceID not in before_sequence_names:
+            break
+    else:
+        raise ValueError("New sequence not found")
+    # rename and return
+    if new_sequence_name is not None:
+        new_seq.name = new_sequence_name
+    return new_seq
+
+
 if __name__ == "__main__":
     pass
